@@ -27,7 +27,7 @@
 int main (int argc, char *argv[])
 {
     const QString name = "Kvantum Manager";
-    const QString version = "0.10.9";
+    const QString version = "0.11.1";
 
     QStringList options;
     for (int i = 1; i < argc; ++i)
@@ -114,7 +114,7 @@ int main (int argc, char *argv[])
     a.installTranslator (&qtTranslator);
 
     QTranslator KMTranslator;
-    KMTranslator.load ("kvantummanager_" + lang, DATADIR "/kvantummanager/translations");
+    KMTranslator.load ("kvantummanager_" + lang, QStringLiteral (DATADIR) + "/kvantummanager/translations");
     a.installTranslator (&KMTranslator);
 
     /* for Kvantum Manager to do its job, it should by styled by Kvantum */
