@@ -28,9 +28,7 @@
 #include "drag/windowmanager.h"
 #include "themeconfig/ThemeConfig.h"
 #include "blur/blurhelper.h"
-#if QT_VERSION >= 0x050500
 #include "animation/animation.h"
-#endif
 
 // definitions shared by source files
 #define SLIDER_TICK_SIZE 5 // 10 at most
@@ -98,6 +96,7 @@ class Style : public QCommonStyle {
     void polish(QPalette &palette);
     void unpolish(QWidget *widget);
     void unpolish(QApplication *app);
+    QPalette standardPalette() const;
 
     virtual bool eventFilter(QObject *o, QEvent *e);
 
@@ -166,6 +165,9 @@ class Style : public QCommonStyle {
       DisabledSelected
     };
 
+    /* Set standard palette colors to the Kvantum theme colors. */
+    void polishStandardPalette() const;
+
     /* Set up a theme with the given name. If there is no name,
        the default theme will be used. If the config or SVG file of
        the theme is missing, that of the default theme will be used. */
@@ -315,6 +317,10 @@ class Style : public QCommonStyle {
 
     /* Can an expanded border be drawn for this frame? */
     bool hasExpandedBorder(const frame_spec &fspec) const;
+    /* Does a flat downward arrow exist? */
+    bool flatArrowExists(const QString &indicatorElement) const;
+    /* Do some elements (like checkbox/radio-buttons for menu/view-item) exit? */
+    bool elementExists(const QString &elementName) const;
 
     /* Get menu margins, including its shadow. */
     int getMenuMargin(bool horiz) const;
@@ -378,11 +384,9 @@ class Style : public QCommonStyle {
     /* The extra combo box width needed by frames and spacings. */
     int extraComboWidth(const QStyleOptionComboBox *opt, bool hasIcon) const;
 
-#if QT_VERSION >= 0x050500
     /* For transient scrollbars: */
     void startAnimation(Animation *animation) const;
     void stopAnimation(const QObject *target) const;
-#endif
 
   private slots:
     /* Called on timer timeout to advance busy progress bars. */
@@ -394,9 +398,7 @@ class Style : public QCommonStyle {
     /* Removes a button from all special lists. */
     void removeFromSet(QObject *o);
 
-#if QT_VERSION >= 0x050500
     void removeAnimation(QObject *animation); // For transient scrollbars
-#endif
 
   private:
     QSvgRenderer *defaultRndr_, *themeRndr_;
@@ -433,9 +435,8 @@ class Style : public QCommonStyle {
 
     /* LibreOffice and Plasma need workarounds. */
     bool isLibreoffice_, isPlasma_;
-    /* So far, only VirtualBox has introduced
-       itself as "Qt-subapplication" and doesn't
-       accept compositing. */
+    /* So far, only VirtualBox has introduced itself as "Qt-subapplication" and
+       doesn't accept compositing. */
     bool subApp_;
     /* Some apps shouldn't have translucent windows. */
     bool isOpaque_;
@@ -450,7 +451,7 @@ class Style : public QCommonStyle {
     /* For identifying KisSliderSpinBox */
     bool isKisSlider_;
 
-    /* For having clear label icons with QT_DEVICE_PIXEL_RATIO > 1 but without AA_UseHighDpiPixmaps */
+    /* For having clear label icons with QT_DEVICE_PIXEL_RATIO > 1 */
     qreal pixelRatio_;
 
     /* Keep track of the sunken button (used instead of a private header for menu positioning). */
@@ -473,14 +474,24 @@ class Style : public QCommonStyle {
     /* For correct updating on mouseover with active tab overlapping */
     QRect tabHoverRect_;
 
-    /* for enforcing the text color of inactive selected items */
+    /* For enforcing the text color of inactive selected items. */
     bool hasInactiveSelItemCol_;
     /* Does the toggled (active but unfocused) view-item have a high contrast with the pressed one? */
     bool toggledItemHasContrast_;
 
-#if QT_VERSION >= 0x050500
+    /* The standard palette (for not setting it frequently): */
+    mutable QPalette standardPalette_;
+
+    /* List of menus drawn by Kvantum and their margins
+       (for preventing redundant computations): */
+    mutable QHash<const QWidget*, QList<int>> drawnMenus_;
+
+    // For not searching the SVG file too often:
+    mutable QHash<const QString, bool>expandedBorders_;
+    mutable QHash<const QString, bool>flatArrows_;
+    mutable QHash<const QString, bool>elements_;
+
     mutable QHash<const QObject*, Animation*> animations_; // For transient scrollbars
-#endif
 };
 }
 
