@@ -22,6 +22,7 @@
 #include <QApplication>
 #include <QMenu>
 #include <QPushButton>
+#include <QCommandLinkButton>
 #include <QCheckBox>
 #include <QRadioButton>
 #include <QToolBox>
@@ -404,13 +405,18 @@ void Style::polish(QWidget *widget)
             /* enable blurring */
             if (!makeTranslucent || tspec_now.blurring)
             {
-              if (!blurHelper_)
+              if (blurHelper_ == nullptr)
               {
-                getShadow(QStringLiteral("Menu"), getMenuMargin(true), getMenuMargin(false));
-                const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
-                int thickness = qMax(qMax(fspec.top,fspec.bottom), qMax(fspec.left,fspec.right));
-                thickness += tspec_now.tooltip_shadow_depth;
-                QList<int> tooltipS = getShadow(QStringLiteral("ToolTip"), thickness);
+                if (tspec_now.menu_shadow_depth > 0)
+                  getShadow(QStringLiteral("Menu"), getMenuMargin(true), getMenuMargin(false));
+                QList<int> tooltipS;
+                if (tspec_now.tooltip_shadow_depth > 0)
+                {
+                  const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
+                  int thickness = qMax(qMax(fspec.top,fspec.bottom), qMax(fspec.left,fspec.right));
+                  thickness += tspec_now.tooltip_shadow_depth;
+                  tooltipS = getShadow(QStringLiteral("ToolTip"), thickness);
+                }
                 blurHelper_ = new BlurHelper(this, menuShadow_, tooltipS,
                                              tspec_.contrast, tspec_.intensity, tspec_.saturation);
               }
@@ -601,7 +607,7 @@ void Style::polish(QWidget *widget)
               if (palette.color(itemView->backgroundRole()) == QColor(Qt::transparent))
               {
                 palette.setColor(itemView->viewport()->backgroundRole(),
-                                 QApplication::palette().color(QPalette::Base));
+                                 standardPalette().color(QPalette::Base));
                 itemView->viewport()->setPalette(palette);
               }
             }
@@ -635,6 +641,8 @@ void Style::polish(QWidget *widget)
         widget->installEventFilter(this);
     }
   }
+  else if (qobject_cast<QCommandLinkButton*>(widget))
+    widget->installEventFilter(this); // to paint it
   else if ((tspec_.animate_states &&
             (qobject_cast<QPushButton*>(widget)
              || (qobject_cast<QToolButton*>(widget)
@@ -704,11 +712,12 @@ void Style::polish(QWidget *widget)
           widget->installEventFilter(this);
         }
         // set the background correctly when scrollbars are either inside the frame or inside a combo popup
-        if ((tspec_.scrollbar_in_view || (widget->inherits("QComboBoxListView") && !tspec_.combo_menu))
+        if ((tspec_.scrollbar_in_view || (widget->inherits("QComboBoxListView")
+                                          && (!tspec_.combo_menu /*|| isLibreoffice_*/)))
             && vp && vp->autoFillBackground()
             && (vp->styleSheet().isEmpty() || !vp->styleSheet().contains("background"))
             // but not when the combo popup is drawn as a menu
-            && !(tspec_.combo_menu && widget->inherits("QComboBoxListView"))
+            && !(tspec_.combo_menu /*&& !isLibreoffice_*/ && widget->inherits("QComboBoxListView"))
             // also consider pcmanfm hacking keys
             && !(isPcmanfm_
                  && ((hspec_.transparent_pcmanfm_view && pw
@@ -781,7 +790,11 @@ void Style::polish(QWidget *widget)
       if (QMainWindow *mw = qobject_cast<QMainWindow*>(pw))
       {
         if (mw->minimumSize() != mw->maximumSize())
-          sb->setSizeGripEnabled(true);
+        {
+          QLayout *lo = mw->layout();
+          if (lo == nullptr || lo->sizeConstraint() != QLayout::SetFixedSize)
+            sb->setSizeGripEnabled(true);
+        }
       }
     }
   }
@@ -796,12 +809,11 @@ void Style::polish(QWidget *widget)
     }
   }
 
-  bool isMenuOrTooltip(!isLibreoffice_ // not required
-                       && !noComposite_
+  bool isMenuOrTooltip(!noComposite_
                        && !subApp_
                        && (qobject_cast<QMenu*>(widget)
                            /* no shadow for tooltips that are already translucent */
-                           || (widget->inherits("QTipLabel")
+                           || (widget->inherits("QTipLabel") && !isLibreoffice_
                                && (!widget->testAttribute(Qt::WA_TranslucentBackground)
                                    || forcedTranslucency_.contains(widget)))));
   if ((isMenuOrTooltip
@@ -814,7 +826,8 @@ void Style::polish(QWidget *widget)
     {
       if (qobject_cast<QMenu*>(widget) || widget->inherits("QComboBoxPrivateContainer"))
       {
-        getShadow(QStringLiteral("Menu"), getMenuMargin(true), getMenuMargin(false));
+        if (tspec_now.menu_shadow_depth > 0)
+          getShadow(QStringLiteral("Menu"), getMenuMargin(true), getMenuMargin(false));
         if (qobject_cast<QMenu*>(widget))
         {
           /* On the one hand, RTL submenus aren't positioned correctly by Qt and, since
@@ -841,12 +854,16 @@ void Style::polish(QWidget *widget)
 
       if (!widget->inherits("QComboBoxPrivateContainer") || tspec_.combo_menu)
       {
-        if (!blurHelper_ && tspec_now.popup_blurring)
+        if (blurHelper_ == nullptr && tspec_now.popup_blurring)
         {
-          const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
-          int thickness = qMax(qMax(fspec.top,fspec.bottom), qMax(fspec.left,fspec.right));
-          thickness += tspec_now.tooltip_shadow_depth;
-          QList<int> tooltipS = getShadow(QStringLiteral("ToolTip"), thickness);
+          QList<int> tooltipS;
+          if (tspec_now.tooltip_shadow_depth > 0)
+          {
+            const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
+            int thickness = qMax(qMax(fspec.top,fspec.bottom), qMax(fspec.left,fspec.right));
+            thickness += tspec_now.tooltip_shadow_depth;
+            tooltipS = getShadow(QStringLiteral("ToolTip"), thickness);
+          }
           blurHelper_ = new BlurHelper(this, menuShadow_, tooltipS,
                                        tspec_.contrast, tspec_.intensity, tspec_.saturation);
         }
@@ -855,7 +872,7 @@ void Style::polish(QWidget *widget)
           blurHelper_->registerWidget(widget);
       }
     }
-    else if (qobject_cast<QMenu*>(widget)) // only for menubar items (see eventFilter -> case QEvent::Show)
+    else if (qobject_cast<QMenu*>(widget)) // for menubars and submenus (eventFilter -> case QEvent::Show)
         widget->installEventFilter(this);
   }
 }
@@ -882,7 +899,7 @@ void Style::polish(QApplication *app)
   /* general colors
      FIXME Is this needed? Can't polish(QPalette&) alone do the job?
      The documentation for QApplication::setPalette() is ambiguous
-     but, at least outside KDE and with Qt4, it's sometimes needed. */
+     but, at least outside KDE and with Qt4, it was sometimes needed. */
   QPalette palette = app->palette();
   polish(palette);
   app->setPalette(palette);
@@ -897,161 +914,7 @@ void Style::polish(QApplication *app)
 
 void Style::polish(QPalette &palette)
 {
-  QColor col1;
-  bool hasInactiveness (!tspec_.no_inactiveness);
-
-  /* background colors */
-  QColor col = getFromRGBA(cspec_.windowColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::Window,col);
-    palette.setColor(QPalette::Disabled,QPalette::Window,col); // used in generatedIconPixmap()
-    col1 = getFromRGBA(cspec_.inactiveWindowColor);
-    if (col1.isValid() && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::Window,col1);
-    else
-      palette.setColor(QPalette::Inactive,QPalette::Window,col);
-  }
-
-  col = getFromRGBA(cspec_.baseColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::Base,col);
-    palette.setColor(QPalette::Disabled,QPalette::Base,col); // some apps may use it
-    col1 = getFromRGBA(cspec_.inactiveBaseColor);
-    if (col1.isValid() && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::Base,col1);
-    else
-      palette.setColor(QPalette::Inactive,QPalette::Base,col);
-  }
-
-  col = getFromRGBA(cspec_.altBaseColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::AlternateBase,col);
-    palette.setColor(QPalette::Disabled,QPalette::AlternateBase,col);
-    col1 = getFromRGBA(cspec_.inactiveAltBaseColor);
-    if (col1.isValid() && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::AlternateBase,col1);
-    else
-      palette.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
-  }
-
-  col = getFromRGBA(cspec_.buttonColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Button,col);
-
-  col = getFromRGBA(cspec_.lightColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Light,col);
-  col = getFromRGBA(cspec_.midLightColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Midlight,col);
-  col = getFromRGBA(cspec_.darkColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Dark,col);
-  col = getFromRGBA(cspec_.midColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Mid,col);
-  col = getFromRGBA(cspec_.shadowColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Shadow,col);
-
-  col = getFromRGBA(cspec_.highlightColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::Highlight,col);
-    palette.setColor(QPalette::Disabled,QPalette::Highlight,col);
-    col1 = getFromRGBA(cspec_.inactiveHighlightColor);
-    if (col1.isValid() && col1 != col && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::Highlight,col1);
-    else
-    {
-      /* NOTE: Qt has a nasty bug which, sometimes, prevents updating of inactive widgets
-               when the active and inactive highlight colors are the same. As a workaround,
-               we make them just a little different from each other. */
-      int v = col.value();
-      if (v == 0) v++; else v--;
-      col.setHsv(col.hue(), col.saturation(), v, col.alpha());
-      palette.setColor(QPalette::Inactive,QPalette::Highlight,col);
-    }
-  }
-
-  col = getFromRGBA(cspec_.tooltipBaseColor);
-  if (col.isValid())
-    palette.setColor(QPalette::ToolTipBase,col);
-  else
-  { // for backward compatibility
-    col = getFromRGBA(cspec_.tooltipTextColor);
-    if (col.isValid())
-    {
-      col1 = QColor(Qt::white);
-      if (qGray(col.rgb()) >= 127)
-        col1 = QColor(Qt::black);
-      palette.setColor(QPalette::ToolTipBase,col1);
-    }
-  }
-
-  /* text colors */
-  col = getFromRGBA(cspec_.textColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::Text,col);
-    col1 = getFromRGBA(cspec_.inactiveTextColor);
-    if (col1.isValid() && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::Text,col1);
-    else
-      palette.setColor(QPalette::Inactive,QPalette::Text,col);
-  }
-
-  col = getFromRGBA(cspec_.windowTextColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::WindowText,col);
-    col1 = getFromRGBA(cspec_.inactiveWindowTextColor);
-    if (col1.isValid() && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::WindowText,col1);
-    else
-      palette.setColor(QPalette::Inactive,QPalette::WindowText,col);
-  }
-
-  col = getFromRGBA(cspec_.buttonTextColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::ButtonText,col);
-    palette.setColor(QPalette::Inactive,QPalette::ButtonText,col);
-  }
-
-  col = getFromRGBA(cspec_.tooltipTextColor);
-  if (col.isValid())
-    palette.setColor(QPalette::ToolTipText,col);
-
-  col = getFromRGBA(cspec_.highlightTextColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Active,QPalette::HighlightedText,col);
-    col1 = getFromRGBA(cspec_.inactiveHighlightTextColor);
-    if (col1.isValid() && hasInactiveness)
-      palette.setColor(QPalette::Inactive,QPalette::HighlightedText,col1);
-    else
-      palette.setColor(QPalette::Inactive,QPalette::HighlightedText,col);
-  }
-
-  col = getFromRGBA(cspec_.linkColor);
-  if (col.isValid())
-    palette.setColor(QPalette::Link,col);
-  col = getFromRGBA(cspec_.linkVisitedColor);
-  if (col.isValid())
-    palette.setColor(QPalette::LinkVisited,col);
-
-  /* disabled text */
-  col = getFromRGBA(cspec_.disabledTextColor);
-  if (col.isValid())
-  {
-    palette.setColor(QPalette::Disabled,QPalette::Text,col);
-    palette.setColor(QPalette::Disabled,QPalette::WindowText,col);
-    palette.setColor(QPalette::Disabled,QPalette::ButtonText,col);
-  }
+  palette = standardPalette();
 }
 
 void Style::unpolish(QWidget *widget)
@@ -1110,6 +973,7 @@ void Style::unpolish(QWidget *widget)
         || qobject_cast<QProgressBar*>(widget)
         || qobject_cast<QAbstractSpinBox*>(widget)
         || qobject_cast<QToolButton*>(widget)
+        || qobject_cast<QCommandLinkButton*>(widget) // we paint it
         || qobject_cast<QComboBox*>(widget) // for both state anomation and delegate
         || (tspec_.active_tab_overlap > 0 && qobject_cast<QTabBar*>(widget))
         || (tspec_.animate_states &&
@@ -1173,4 +1037,173 @@ void Style::unpolish(QApplication *app)
   QCommonStyle::unpolish(app);
 }
 
+/* Set the standard palette to the Kvantum theme palette
+   (to be used in the code because QApplication::palette()
+   may not be reliable with apps like Qt Designer). */
+QPalette Style::standardPalette() const
+{
+  if (standardPalette_.isBrushSet(QPalette::Active,QPalette::Base))
+    return standardPalette_;
+
+  QColor col1;
+  bool hasInactiveness (!tspec_.no_inactiveness);
+
+  /* background colors */
+  QColor col = getFromRGBA(cspec_.windowColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::Window,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::Window,col); // used in generatedIconPixmap()
+    col1 = getFromRGBA(cspec_.inactiveWindowColor);
+    if (col1.isValid() && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Window,col1);
+    else
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Window,col);
+  }
+
+  col = getFromRGBA(cspec_.baseColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::Base,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::Base,col); // some apps may use it
+    col1 = getFromRGBA(cspec_.inactiveBaseColor);
+    if (col1.isValid() && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Base,col1);
+    else
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Base,col);
+  }
+  else // just to know that all brushes are set
+    standardPalette_.setColor(QPalette::Active,QPalette::Base,QColor(Qt::white));
+
+  col = getFromRGBA(cspec_.altBaseColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::AlternateBase,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::AlternateBase,col);
+    col1 = getFromRGBA(cspec_.inactiveAltBaseColor);
+    if (col1.isValid() && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col1);
+    else
+      standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
+  }
+
+  col = getFromRGBA(cspec_.buttonColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Button,col);
+
+  col = getFromRGBA(cspec_.lightColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Light,col);
+  col = getFromRGBA(cspec_.midLightColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Midlight,col);
+  col = getFromRGBA(cspec_.darkColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Dark,col);
+  col = getFromRGBA(cspec_.midColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Mid,col);
+  col = getFromRGBA(cspec_.shadowColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Shadow,col);
+
+  col = getFromRGBA(cspec_.highlightColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::Highlight,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::Highlight,col);
+    col1 = getFromRGBA(cspec_.inactiveHighlightColor);
+    if (col1.isValid() && col1 != col && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Highlight,col1);
+    else
+    {
+      /* NOTE: Qt has a nasty bug which, sometimes, prevents updating of inactive widgets
+               when the active and inactive highlight colors are the same. As a workaround,
+               we make them just a little different from each other. */
+      int v = col.value();
+      if (v == 0) v++; else v--;
+      col.setHsv(col.hue(), col.saturation(), v, col.alpha());
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Highlight,col);
+    }
+  }
+
+  col = getFromRGBA(cspec_.tooltipBaseColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::ToolTipBase,col);
+  else
+  { // for backward compatibility
+    col = getFromRGBA(cspec_.tooltipTextColor);
+    if (col.isValid())
+    {
+      col1 = QColor(Qt::white);
+      if (qGray(col.rgb()) >= 127)
+        col1 = QColor(Qt::black);
+      standardPalette_.setColor(QPalette::ToolTipBase,col1);
+    }
+  }
+
+  /* text colors */
+  col = getFromRGBA(cspec_.textColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::Text,col);
+    col1 = getFromRGBA(cspec_.inactiveTextColor);
+    if (col1.isValid() && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Text,col1);
+    else
+      standardPalette_.setColor(QPalette::Inactive,QPalette::Text,col);
+  }
+
+  col = getFromRGBA(cspec_.windowTextColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::WindowText,col);
+    col1 = getFromRGBA(cspec_.inactiveWindowTextColor);
+    if (col1.isValid() && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::WindowText,col1);
+    else
+      standardPalette_.setColor(QPalette::Inactive,QPalette::WindowText,col);
+  }
+
+  col = getFromRGBA(cspec_.buttonTextColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::ButtonText,col);
+    standardPalette_.setColor(QPalette::Inactive,QPalette::ButtonText,col);
+  }
+
+  col = getFromRGBA(cspec_.tooltipTextColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::ToolTipText,col);
+
+  col = getFromRGBA(cspec_.highlightTextColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Active,QPalette::HighlightedText,col);
+    col1 = getFromRGBA(cspec_.inactiveHighlightTextColor);
+    if (col1.isValid() && hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::HighlightedText,col1);
+    else
+      standardPalette_.setColor(QPalette::Inactive,QPalette::HighlightedText,col);
+  }
+
+  col = getFromRGBA(cspec_.linkColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::Link,col);
+  col = getFromRGBA(cspec_.linkVisitedColor);
+  if (col.isValid())
+    standardPalette_.setColor(QPalette::LinkVisited,col);
+
+  /* disabled text */
+  col = getFromRGBA(cspec_.disabledTextColor);
+  if (col.isValid())
+  {
+    standardPalette_.setColor(QPalette::Disabled,QPalette::Text,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::WindowText,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::ButtonText,col);
+  }
+
+  return standardPalette_;
+}
+
 }
