@@ -24,6 +24,7 @@
 #include <QComboBox>
 #include <QDockWidget>
 #include <QSvgRenderer>
+#include <QMdiSubWindow>
 
 namespace Kvantum
 {
@@ -33,10 +34,8 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
                           const QWidget *widget) const
 {
   bool hdpi(false);
-#if QT_VERSION >= 0x050500
   if (qApp->testAttribute(Qt::AA_UseHighDpiPixmaps))
     hdpi = true;
-#endif
   const bool rtl(option != nullptr ? option->direction == Qt::RightToLeft
                                    : QApplication::layoutDirection() == Qt::RightToLeft);
   switch (standardIcon) {
@@ -143,6 +142,13 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
+      /* no menu icon without enough contrast (see Qt ->
+         qmdisubwindow.cpp -> QMdiSubWindowPrivate::createSystemMenu) */
+      if (option == nullptr && qobject_cast<const QMdiSubWindow*>(widget)
+          && enoughContrast(getFromRGBA(getLabelSpec(QStringLiteral("MenuItem")).normalColor),
+                            getFromRGBA(getLabelSpec(QStringLiteral("TitleBar")).focusColor)))
+       return QIcon(pm);
+
       QPainter painter(&pm);
 
       QString status("normal");
@@ -151,7 +157,9 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
                    (option->state & State_Sunken) ? "pressed" :
                    (option->state & State_MouseOver) ? "focused" : "normal"
                  : "disabled";
-      if (renderElement(&painter,getIndicatorSpec(QStringLiteral("TitleBar")).element+"-minimize-"+status,QRect(0,0,s,s)))
+      if (renderElement(&painter,
+                        getIndicatorSpec(QStringLiteral("TitleBar")).element+"-minimize-"+status,
+                        QRect(0,0,s,s)))
         return QIcon(pm);
       else break;
     }
@@ -164,6 +172,11 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
+      if (option == nullptr && qobject_cast<const QMdiSubWindow*>(widget)
+          && enoughContrast(getFromRGBA(getLabelSpec(QStringLiteral("MenuItem")).normalColor),
+                            getFromRGBA(getLabelSpec(QStringLiteral("TitleBar")).focusColor)))
+       return QIcon(pm); // no menu icon without enough contrast
+
       QPainter painter(&pm);
 
       if (renderElement(&painter,getIndicatorSpec(QStringLiteral("TitleBar")).element+"-maximize-normal",QRect(0,0,s,s)))
@@ -180,6 +193,12 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
+      if (standardIcon == SP_TitleBarCloseButton
+          && option == nullptr && qobject_cast<const QMdiSubWindow*>(widget)
+          && enoughContrast(getFromRGBA(getLabelSpec(QStringLiteral("MenuItem")).normalColor),
+                            getFromRGBA(getLabelSpec(QStringLiteral("TitleBar")).focusColor)))
+       return QIcon(pm); // no menu icon without enough contrast
+
       QPainter painter(&pm);
 
       QString status("normal");
@@ -194,10 +213,14 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       if (standardIcon == SP_DockWidgetCloseButton
           || qobject_cast<const QDockWidget*>(widget))
       {
-        rendered = renderElement(&painter,getIndicatorSpec(QStringLiteral("Dock")).element+"-close",QRect(0,0,s,s));
+        rendered = renderElement(&painter,
+                                 getIndicatorSpec(QStringLiteral("Dock")).element+"-close",
+                                 QRect(0,0,s,s));
       }
       if (!rendered)
-        rendered = renderElement(&painter,getIndicatorSpec(QStringLiteral("TitleBar")).element+"-close-"+status,QRect(0,0,s,s));
+        rendered = renderElement(&painter,
+                                 getIndicatorSpec(QStringLiteral("TitleBar")).element+"-close-"+status,
+                                 QRect(0,0,s,s));
       if (rendered)
         return QIcon(pm);
       else break;
@@ -226,6 +249,11 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       QPixmap pm(QSize(s,s));
       pm.fill(Qt::transparent);
 
+      if (option == nullptr && qobject_cast<const QMdiSubWindow*>(widget)
+          && enoughContrast(getFromRGBA(getLabelSpec(QStringLiteral("MenuItem")).normalColor),
+                            getFromRGBA(getLabelSpec(QStringLiteral("TitleBar")).focusColor)))
+       return QIcon(pm); // no menu icon without enough contrast
+
       QPainter painter(&pm);
 
       QString status("normal");
@@ -238,9 +266,13 @@ QIcon Style::standardIcon(QStyle::StandardPixmap standardIcon,
       }
       bool rendered(false);
       if (qobject_cast<const QDockWidget*>(widget))
-        rendered = renderElement(&painter,getIndicatorSpec(QStringLiteral("Dock")).element+"-restore",QRect(0,0,s,s));
+        rendered = renderElement(&painter,
+                                 getIndicatorSpec(QStringLiteral("Dock")).element+"-restore",
+                                 QRect(0,0,s,s));
       if (!rendered)
-        rendered = renderElement(&painter,getIndicatorSpec(QStringLiteral("TitleBar")).element+"-restore-"+status,QRect(0,0,s,s));
+        rendered = renderElement(&painter,
+                                 getIndicatorSpec(QStringLiteral("TitleBar")).element+"-restore-"+status,
+                                 QRect(0,0,s,s));
       if (rendered)
         return QIcon(pm);
       else break;
