@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -48,6 +48,7 @@ ThemeConfig::ThemeConfig(const QString& theme) :
 #endif
 
   load(theme);
+  default_theme_spec(compositeSpecs_);
 }
 
 ThemeConfig::~ThemeConfig()
@@ -374,38 +375,44 @@ label_spec ThemeConfig::getLabelSpec(const QString &elementName)
       r.toggleInactiveColor = v.toString();
     }
 
-    v = getValue(elementName,KSL("text.bold"), i);
-    r.boldFont = v.toBool();
+    /* because finding longest texts of combo boxes isn't CPU-friendly and since
+       combos can have menu popups, we don't make menu and combo texts bold or italic */
+    if (elementName != "MenuItem"
+        && elementName != "ComboBox" && elementName != "ToolbarComboBox")
+    {
+      v = getValue(elementName,KSL("text.bold"), i);
+      r.boldFont = v.toBool();
 
 #if QT_VERSION >= 0x050000
-    v = getValue(elementName,KSL("text.boldness"), i);
-    if (v.isValid()) // QFont::Bold by default
-    {
-      int b = qMin(qMax(v.toInt(),1),5);
-      switch (b) {
-        case 1:
-          r.boldness = QFont::Medium;
-          break;
-        case 2:
-          r.boldness = QFont::DemiBold;
-          break;
-        case 3:
-          r.boldness = QFont::Bold;
-          break;
-        case 4:
-          r.boldness = QFont::ExtraBold;
-          break;
-        case 5:
-          r.boldness = QFont::Black;
-          break;
-        default:
-          r.boldness = QFont::Bold;
+      v = getValue(elementName,KSL("text.boldness"), i);
+      if (v.isValid()) // QFont::Bold by default
+      {
+        int b = qMin(qMax(v.toInt(),1),5);
+        switch (b) {
+          case 1:
+            r.boldness = QFont::Medium;
+            break;
+          case 2:
+            r.boldness = QFont::DemiBold;
+            break;
+          case 3:
+            r.boldness = QFont::Bold;
+            break;
+          case 4:
+            r.boldness = QFont::ExtraBold;
+            break;
+          case 5:
+            r.boldness = QFont::Black;
+            break;
+          default:
+            r.boldness = QFont::Bold;
+        }
       }
-    }
 #endif
 
-    v = getValue(elementName,KSL("text.italic"), i);
-    r.italicFont = v.toBool();
+      v = getValue(elementName,KSL("text.italic"), i);
+      r.italicFont = v.toBool();
+    }
 
     if (r.hasShadow)
     {
@@ -540,16 +547,14 @@ size_spec ThemeConfig::getSizeSpec(const QString& elementName)
 
 theme_spec ThemeConfig::getCompositeSpec()
 {
-  theme_spec r;
-  default_theme_spec(r);
-  QVariant v;
+  bool compositing(false);
 
 #if defined Q_WS_X11 || defined Q_OS_LINUX
   /* set to false if no compositing manager is running */
 #if QT_VERSION < 0x050200
   if (QX11Info::isCompositingManagerRunning())
+    compositing = true;
 #else
-  bool compositing = false;
   if (isX11_)
   {
     Atom atom = XInternAtom (QX11Info::display(), "_NET_WM_CM_S0", False);
@@ -558,100 +563,87 @@ theme_spec ThemeConfig::getCompositeSpec()
   }
   else
     compositing = true; // wayland is always composited
-  if (compositing)
 #endif
-  {
-    v = getValue(KSL("General"),KSL("composite"));
-    r.composite = v.toBool();
-  }
-#elif (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
-  v = getValue(KSL("General"),KSL("composite"));
-  r.composite = v.toBool();
+/*#elif (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+  compositing = true; // presuppose a compositor without Linux and X11*/
 #endif
 
   /* no blurring or window translucency without compositing */
-  if (/*isX11_ &&*/ r.composite)
+  if (compositing)
   {
+    if (compositeSpecs_.hasCompositor)
+      return compositeSpecs_;
+
+    compositeSpecs_.hasCompositor = true;
+
+    QVariant v = getValue(KSL("General"),KSL("composite"));
+    compositeSpecs_.composite = v.toBool();
+
     /* no window translucency or blurring without
        window interior element or reduced opacity */
-
-    interior_spec ispec = getInteriorSpec(KSL("WindowTranslucent"));
-    if (ispec.element.isEmpty())
-      ispec = getInteriorSpec(KSL("Window"));
-
-    if (ispec.hasInterior
-        || getValue(KSL("General"),KSL("reduce_window_opacity")).toInt() > 0)
+    if (compositeSpecs_.composite)
     {
-      v = getValue(KSL("General"),KSL("translucent_windows"));
-      if (v.isValid())
-        r.translucent_windows = v.toBool();
+      interior_spec ispec = getInteriorSpec(KSL("WindowTranslucent"));
+      if (ispec.element.isEmpty())
+        ispec = getInteriorSpec(KSL("Window"));
 
-      /* no window blurring without window translucency */
-#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
-      if (r.translucent_windows)
-#else
-      if (isX11_ && r.translucent_windows)
-#endif
+      if (ispec.hasInterior
+          || getValue(KSL("General"),KSL("reduce_window_opacity")).toInt() > 0)
       {
-        v = getValue(KSL("General"),KSL("blurring"));
+        v = getValue(KSL("General"),KSL("translucent_windows"));
         if (v.isValid())
-          r.blurring = v.toBool();
-      }
-    }
+          compositeSpecs_.translucent_windows = v.toBool();
 
-    /* "blurring" is sufficient but not necessary for "popup_blurring" */
-#if (QT_VERSION < QT_VERSION_CHECK(5,11,0))
-    if (isX11_)
-    {
+        /* no window blurring without window translucency */
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+        if (compositeSpecs_.translucent_windows)
+#else
+        if (isX11_ && compositeSpecs_.translucent_windows)
 #endif
-      if (r.blurring)
-        r.popup_blurring = true;
-      else
-      {
-        interior_spec ispecM = getInteriorSpec(KSL("Menu"));
-        interior_spec ispecT = getInteriorSpec(KSL("ToolTip"));
-        if (ispecM.hasInterior || ispecT.hasInterior)
         {
-          v = getValue(KSL("General"),KSL("popup_blurring"));
+          v = getValue(KSL("General"),KSL("blurring"));
           if (v.isValid())
-            r.popup_blurring = v.toBool();
+            compositeSpecs_.blurring = v.toBool();
         }
       }
+
+      /* "blurring" is sufficient but not necessary for "popup_blurring" */
 #if (QT_VERSION < QT_VERSION_CHECK(5,11,0))
-    }
+      if (isX11_)
+      {
 #endif
+        if (compositeSpecs_.blurring)
+          compositeSpecs_.popup_blurring = true;
+        else
+        {
+          interior_spec ispecM = getInteriorSpec(KSL("Menu"));
+          interior_spec ispecT = getInteriorSpec(KSL("ToolTip"));
+          if (ispecM.hasInterior || ispecT.hasInterior)
+          {
+            v = getValue(KSL("General"),KSL("popup_blurring"));
+            if (v.isValid())
+              compositeSpecs_.popup_blurring = v.toBool();
+          }
+        }
+#if (QT_VERSION < QT_VERSION_CHECK(5,11,0))
+      }
+#endif
+
+      /* no menu/tooltip shadow without compositing */
+      v = getValue(KSL("General"),KSL("menu_shadow_depth"));
+      if (v.isValid())
+        compositeSpecs_.menu_shadow_depth = qMax(v.toInt(),0);
+
+      v = getValue(KSL("General"),KSL("tooltip_shadow_depth"));
+      if (v.isValid())
+        compositeSpecs_.tooltip_shadow_depth = qMax(v.toInt(),0);
+    }
+
+    return compositeSpecs_;
   }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
-  /* NOTE: The contrast effect is applied by BlurHelper, so that the following values have
-           effect only for windows that can be blurred, whether they are blurred or not. */
-  v = getValue(KSL("General"),KSL("contrast"));
-  if (v.isValid()) // 1 by default
-    r.contrast = qBound (static_cast<qreal>(0), v.toReal(), static_cast<qreal>(2));
-  v = getValue(KSL("General"),KSL("intensity"));
-  if (v.isValid()) // 1 by default
-    r.intensity = qBound (static_cast<qreal>(0), v.toReal(), static_cast<qreal>(2));
-  v = getValue(KSL("General"),KSL("saturation"));
-  if (v.isValid()) // 1 by default
-    r.saturation = qBound (static_cast<qreal>(0), v.toReal(), static_cast<qreal>(2));
-#endif
-
-  /* no menu/tooltip shadow without compositing */
-  v = getValue(KSL("General"),KSL("menu_shadow_depth"));
-  if (v.isValid() && r.composite)
-    r.menu_shadow_depth = qMax(v.toInt(),0);
-
-  v = getValue(KSL("General"),KSL("menu_separator_height"));
-  if (v.isValid())
-    r.menu_separator_height = qMin(qMax(v.toInt(),1),16);
-
-  v = getValue(KSL("General"),KSL("spread_menuitems"));
-  r.spread_menuitems = v.toBool();
-
-  v = getValue(KSL("General"),KSL("tooltip_shadow_depth"));
-  if (v.isValid() && r.composite)
-    r.tooltip_shadow_depth = qMax(v.toInt(),0);
-
+  theme_spec r;
+  default_theme_spec(r);
   return r;
 }
 
@@ -671,13 +663,37 @@ theme_spec ThemeConfig::getThemeSpec()
     r.comment = v.toString();
 
   v = getValue(KSL("General"),KSL("reduce_window_opacity"));
-  if (v.isValid())
+  if (v.isValid()) // compositing will be checked by the code
     r.reduce_window_opacity = qMin(qMax(v.toInt(),0),90);
 
   v = getValue(KSL("General"),KSL("reduce_menu_opacity"));
-  if (v.isValid())
+  if (v.isValid()) // compositing will be checked by the code
     r.reduce_menu_opacity = qMin(qMax(v.toInt(),0),90);
 
+  v = getValue(KSL("General"),KSL("menu_separator_height"));
+  if (v.isValid())
+    r.menu_separator_height = qMin(qMax(v.toInt(),1),16);
+
+  v = getValue(KSL("General"),KSL("spread_menuitems"));
+  r.spread_menuitems = v.toBool();
+
+  v = getValue(KSL("General"),KSL("shadowless_popup"));
+  r.shadowless_popup = v.toBool();
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+    /* NOTE: The contrast effect is applied by BlurHelper, so that the following values have
+             effect only for windows that can be blurred, whether they are blurred or not. */
+  v = getValue(KSL("General"),KSL("contrast"));
+  if (v.isValid()) // 1 by default
+    r.contrast = qBound (static_cast<qreal>(0), v.toReal(), static_cast<qreal>(2));
+  v = getValue(KSL("General"),KSL("intensity"));
+  if (v.isValid()) // 1 by default
+    r.intensity = qBound (static_cast<qreal>(0), v.toReal(), static_cast<qreal>(2));
+  v = getValue(KSL("General"),KSL("saturation"));
+  if (v.isValid()) // 1 by default
+    r.saturation = qBound (static_cast<qreal>(0), v.toReal(), static_cast<qreal>(2));
+#endif
+
   v = getValue(KSL("General"),KSL("x11drag"));
   if (v.isValid()) // "WindowManager::DRAG_ALL" by default
   {
@@ -871,6 +887,9 @@ theme_spec ThemeConfig::getThemeSpec()
   v = getValue(KSL("General"),KSL("inline_spin_indicators"));
   r.inline_spin_indicators = v.toBool();
 
+  v = getValue(KSL("General"),KSL("inline_spin_separator"));
+  r.inline_spin_separator = v.toBool();
+
   v = getValue(KSL("General"),KSL("spin_button_width"));
   if (v.isValid()) // 16 by default
     r.spin_button_width = qMin(qMax(v.toInt(),16), 32);
