@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -97,6 +97,8 @@ typedef struct {
   bool spread_header;
   /* enable mouse tracking in menubars? */
   bool menubar_mouse_tracking;
+  /* is compositing available (used internally) */
+  bool hasCompositor;
   /* use composite effects
      (for now, only translucent menus
      or tooltips and their shadows) */
@@ -135,6 +137,8 @@ typedef struct {
   int submenu_delay;
   /* depth of tooltip shadows */
   int tooltip_shadow_depth;
+  /* no menu or tooltip shadow with compositing? */
+  bool shadowless_popup;
   /* splitter width */
   int splitter_width;
   /* scrollbar width */
@@ -166,6 +170,8 @@ typedef struct {
   /* draw spin indicators horizontally
      but inside the spin line-edit? */
   bool inline_spin_indicators;
+  /* draw the spin separator for inline spin indicators too? */
+  bool inline_spin_separator;
   /* width of a horizontal spin button */
   int spin_button_width;
   /* draw an editable combobox as a lineedit with arrow? */
@@ -485,6 +491,7 @@ static inline void default_theme_spec(theme_spec &tspec) {
   tspec.progressbar_thickness = 0;
   tspec.spread_header = false;
   tspec.menubar_mouse_tracking = true;
+  tspec.hasCompositor = false;
   tspec.composite = false;
   tspec.translucent_windows = false;
   tspec.reduce_window_opacity = 0;
@@ -504,6 +511,7 @@ static inline void default_theme_spec(theme_spec &tspec) {
   tspec.submenu_overlap = 0;
   tspec.submenu_delay = 250;
   tspec.tooltip_shadow_depth = 0;
+  tspec.shadowless_popup = false;
   tspec.splitter_width = 7;
   tspec.scroll_width = 12;
   tspec.scroll_min_extent = 36;
@@ -518,6 +526,7 @@ static inline void default_theme_spec(theme_spec &tspec) {
   tspec.tooltip_delay = -1;
   tspec.vertical_spin_indicators = false;
   tspec.inline_spin_indicators = false;
+  tspec.inline_spin_separator = false;
   tspec.spin_button_width = 16;
   tspec.combo_as_lineedit = false;
   tspec.square_combo_button = false;
